#include <openssl/ssl.h>

namespace ArcMCCTLS {

bool GlobusSetVerifyCertCallback(SSL_CTX* sslctx);

} // namespace Arc

